| getMoonTimes | R Documentation |
Get Moon times
getMoonTimes(
date = NULL,
lat = NULL,
lon = NULL,
data = NULL,
keep = c("rise", "set", "alwaysUp", "alwaysDown"),
tz = "UTC",
...
)
date |
|
lat |
|
lon |
|
data |
|
keep |
|
tz |
|
... |
Not used. (Maintenance only) |
Available variables are :
Date. moonrise time
Date. moonset time
Logical. TRUE if the moon never rises or sets and is always above the horizon during the day
Logical. TRUE if the moon is always below the horizon
data.frame
Other suncalc functions:
getMoonIllumination(),
getMoonPosition(),
getSunlightPosition(),
getSunlightTimes()
# one date
getMoonTimes(date = Sys.Date(), lat = 47.21, lon = -1.557, tz = "CET")
# multiple date + subset
getMoonTimes(date = seq.Date(Sys.Date()-9, Sys.Date(), by = 1),
keep = c("rise", "set", "alwaysUp"),
lat = 47.21, lon = -1.557, tz = "CET")
# multiple coordinates
data <- data.frame(date = seq.Date(Sys.Date()-9, Sys.Date(), by = 1),
lat = c(rep(50.1, 10), rep(49, 10)),
lon = c(rep(1.83, 10), rep(2, 10)))
getMoonTimes(data = data, tz = "CET")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.